# Build Sage 9.5.rc1 from downloaded tarball on Cygwin

2022-01-13


## Overview

On Cygwin 3.3.3-1 on Windows 10, an attempt by Samuel Lelièvre
to build Sage 9.5.rc1 from downloaded tarball.

The build fails on `sagemath_doc_html-none`.

Since `sagelib` is built, most of Sage can be used,
especially if running `make -k -s V=0` which will,
despite the failure, build as many things as possible.

It would be nice for the build to complete though.


## Setup

Laptop

- Acer Aspire A314-22
- Processor: AMD Ryzen 5 3500U with Radeon Vega Mobile Gfx 2.10 GHz
- Memory: Installed RAM: 8 GB

System

- Windows 10 Home, version 21H2, build 19044.1466
- Cygwin 3.3.3-1
- Many Cygwin packages, see cygcheck


## Files

- `README.md`: the present file
- `cygcheck-c-2022-01-13.md`: output of `cygcheck -c`
- `cygcheck-srv-2022-01-13.md`: output of `cygcheck -s -r -v`
- `config.log`
- `install.log`
- `sagemath_doc_html-none.log`


## Session outline

Some checks

```
$ cygcheck -c cygwin
```

Some name choices

```
$ PROJECT=sage-9-5-c1-from-tgz
$ DATE=2022-01-13
$ THE_REPORT=slel-$DATE-cyg-$PROJECT
```

Create report folder

```
$ REPORTS=$HOME/sage-reports
$ REPORT=$REPORTS/$THE_REPORT
$ mkdir -p $REPORT
```

Create fresh readme possibly from template

```
$ touch $REPORT/README.md
$ rsync $REPORTS/reporting/template-report-README.md $REPORT/README.md
```

Some Cygwin package information

```
$ cygcheck -c > $REPORT/cygcheck-c-$DATE.txt
```

Download and extract Sage 9.5.rc1 source tarball, check version

```
$ cd $HOME
$ wget https://mirrors.mit.edu/sage/devel/sage-9.5.rc1.tar.gz
$ tar xf sage-9.5.rc1.tar.gz
$ mv sage-9.5.rc1 $PROJECT
$ cd $PROJECT
$ git branch -vv
```

Check the latest changes

```
$ git log --oneline --first-parent 9.5.rc0^..HEAD
```

Configure (using the `configure` script provided in the tarball) and build

```
$ export MAKE='make -j1'
$ ./configure -q && make -s V=0 testlong
```

Copy relevant logs to report folder

```
$ rsync -a config.log $REPORT
$ rsync -a logs/install.log $REPORT
$ rsync -a logs/pkgs/sagemath_doc_html-none.log $REPORT
$ rsync -a logs $REPORT
$ rsync -a config.log logs $REPORT
```

Edit & proofread README, zip & upload report, and report to sage-release or Sage Trac

```
$ (cd $REPORTS && zip -r $THE_REPORT.zip $THE_REPORT)
$ rsync -a $THE_REPORT.zip me@example.com:www/sage/logs
```


## Session details

Bash prompts set to `PS1='\n$ '` and `PS2='  '` for readability.

```
$ #   ===   PROJECT: Sage 9.5.rc1 from tarball   ===

$ PROJECT=sage-9-5-c1-from-tgz

$ DATE=2022-01-13

$ THE_REPORT=slel-$DATE-cyg-$PROJECT

$ REPORTS=$HOME/sage-reports

$ REPORT=$REPORTS/$THE_REPORT

$ mkdir -p $REPORT

$ rsync $REPORTS/reporting/template-report-README.md $REPORT/README.md

$ cygcheck -c > $REPORT/cygcheck-c-$DATE.txt

$ cd $HOME

$ wget https://mirrors.mit.edu/sage/devel/sage-9.5.rc1.tar.gz
...
2022-01-13 05:42:59 (7.23 MB/s) - ‘sage-9.5.rc1.tar.gz’ saved [1440775330/1440775330]

$ tar xf sage-9.5.rc1.tar.gz

$ mv sage-9.5.rc1 $PROJECT

$ cd $PROJECT

$ git branch -vv
* develop 3da1b22c25 [trac/develop] Updated SageMath version to 9.5.rc1

$ git log --oneline --first-parent 9.5.rc0^..HEAD
3da1b22c25 (HEAD -> develop, tag: 9.5.rc1, trac/develop, trac/HEAD) Updated SageMath version to 9.5.rc1
8e7a22529e Trac #33145: fedora-{26,27,28,...}-minimal: pyzmq build failure
92bd273637 Trac #33138: Fix SAGE_FAT_BINARY regression for numpy ("Ignoring --build-option when building numpy using PEP 517")
164685913f Trac #32744: composite elliptic-curve isogenies
9a48a8a4cb Trac #32502: make WeierstrassIsomorphism behave (more) like EllipticCurveIsogeny
2846293836 Trac #33014: Update ore_algebra to latest version
de2bfc6269 Trac #33111: Update installation manual section "Setting up SageMath as a Jupyter kernel"
91cdefb5ce Trac #33130: Fix silent "sage -b" after #32759
2e4b8bef73 Trac #33135: Filter out some distutils deprecation warnings with python 3.10
cee501534d Trac #33143: Matplotlib update breaks build on debian buster
38323507f6 (tag: 9.5.rc0) Updated SageMath version to 9.5.rc0

$ export MAKE='make -j1'

$ ./configure -q && make -s V=0 testlong
*** The ppl-config script installed by PPL could not be found.
*** If the PPL was installed in PREFIX, make sure PREFIX/bin is in
*** your path, or set the PPL_CONFIG environment variable to the
*** full path to ppl-config.
./configure: line 39349: ,: command not found
*** ALL ENVIRONMENT VARIABLES BEFORE BUILD: ***
!::=::\
_=/usr/bin/env
ALLUSERSPROFILE=C:\ProgramData
APPDATA=C:\Users\s\AppData\Roaming
CommonProgramFiles(x86)=C:\Program Files (x86)\Common Files
COMMONPROGRAMFILES=C:\Program Files\Common Files
CommonProgramW6432=C:\Program Files\Common Files
COMPUTERNAME=LAPTOP-Q6AFHV1S
COMSPEC=C:\WINDOWS\system32\cmd.exe
DriverData=C:\Windows\System32\Drivers\DriverData
EXECIGNORE=*.dll
FPS_BROWSER_APP_PROFILE_STRING=Internet Explorer
FPS_BROWSER_USER_PROFILE_STRING=Default
HOME=/home/s
HOMEDRIVE=C:
HOMEPATH=\Users\s
HOSTNAME=Uc
INFOPATH=/usr/local/info:/usr/share/info:/usr/info
LANG=en_US.utf8
LANGUAGE=en_US.utf8
LC_ALL=en_US.utf8
LC_CTYPE=en_US.utf8
LOCALAPPDATA=C:\Users\s\AppData\Local
LOGONSERVER=\\LAPTOP-Q6AFHV1S
MAKE_TERMERR=/dev/pty1
MAKE_TERMOUT=/dev/pty1
MAKE=make -j1
MAKEFLAGS=s -- V=0 V=1
MAKELEVEL=1
MAKEOVERRIDES=${-*-command-variables-*-}
MFLAGS=-s
MINTTY_SHORTCUT=/cygdrive/c/Users/s/AppData/Roaming/Microsoft/Internet Explorer/Quick Launch/User Pinned/TaskBar/Cygwin64 Terminal.lnk
NUMBER_OF_PROCESSORS=8
OLDPWD=/home/s/sage-9-5-c1-from-tgz
OneDrive=C:\Users\s\OneDrive
ORIGINAL_PATH=/cygdrive/c/WINDOWS/system32:/cygdrive/c/WINDOWS:/cygdrive/c/WINDOWS/System32/Wbem:/cygdrive/c/WINDOWS/System32/WindowsPowerShell/v1.0:/cygdrive/c/WINDOWS/System32/OpenSSH:/cygdrive/c/Users/s/AppData/Local/Microsoft/WindowsApps
OS=Windows_NT
PATH=/home/s/sage-9-5-c1-from-tgz/build/bin:/home/s/sage-9-5-c1-from-tgz/src/bin:/home/s/sage-9-5-c1-from-tgz/local/bin:/usr/local/bin:/usr/bin:/cygdrive/c/WINDOWS/system32:/cygdrive/c/WINDOWS:/cygdrive/c/WINDOWS/System32/Wbem:/cygdrive/c/WINDOWS/System32/WindowsPowerShell/v1.0:/cygdrive/c/WINDOWS/System32/OpenSSH:/cygdrive/c/Users/s/AppData/Local/Microsoft/WindowsApps:/usr/lib/lapack
PATHEXT=.COM;.EXE;.BAT;.CMD;.VBS;.VBE;.JS;.JSE;.WSF;.WSH;.MSC
PRINTER=Microsoft Print to PDF
PROCESSOR_ARCHITECTURE=AMD64
PROCESSOR_IDENTIFIER=AMD64 Family 23 Model 24 Stepping 1, AuthenticAMD
PROCESSOR_LEVEL=23
PROCESSOR_REVISION=1801
PROFILEREAD=true
ProgramData=C:\ProgramData
ProgramFiles(x86)=C:\Program Files (x86)
PROGRAMFILES=C:\Program Files
ProgramW6432=C:\Program Files
PSModulePath=C:\Program Files\WindowsPowerShell\Modules;C:\WINDOWS\system32\WindowsPowerShell\v1.0\Modules
PUBLIC=C:\Users\Public
PWD=/home/s/sage-9-5-c1-from-tgz/build/make
PYTHONPATH=/home/s/sage-9-5-c1-from-tgz/local
SAGE_ENV_CONFIG_SOURCED=1
SAGE_LOCAL=/home/s/sage-9-5-c1-from-tgz/local
SAGE_LOGFILE=logs/install.log
SAGE_LOGS=/home/s/sage-9-5-c1-from-tgz/logs/pkgs
SAGE_NUM_THREADS_PARALLEL=1
SAGE_NUM_THREADS=1
SAGE_ORIG_PATH_SET=True
SAGE_ORIG_PATH=/usr/local/bin:/usr/bin:/cygdrive/c/WINDOWS/system32:/cygdrive/c/WINDOWS:/cygdrive/c/WINDOWS/System32/Wbem:/cygdrive/c/WINDOWS/System32/WindowsPowerShell/v1.0:/cygdrive/c/WINDOWS/System32/OpenSSH:/cygdrive/c/Users/s/AppData/Local/Microsoft/WindowsApps:/usr/lib/lapack
SAGE_PKGCONFIG=/home/s/sage-9-5-c1-from-tgz/local/lib/pkgconfig
SAGE_ROOT=/home/s/sage-9-5-c1-from-tgz
SAGE_SHARE=/home/s/sage-9-5-c1-from-tgz/local/share
SAGE_SILENT_BUILD=yes
SAGE_SRC=/home/s/sage-9-5-c1-from-tgz/src
SESSIONNAME=Console
SHELL=/bin/bash
SHLVL=4
SYSTEMDRIVE=C:
SYSTEMROOT=C:\WINDOWS
TEMP=/tmp
TERM_PROGRAM_VERSION=3.5.2
TERM_PROGRAM=mintty
TERM=xterm
TMP=/tmp
TZ=Europe/Paris
USER=s
USERDOMAIN_ROAMINGPROFILE=LAPTOP-Q6AFHV1S
USERDOMAIN=LAPTOP-Q6AFHV1S
USERNAME=s
USERPROFILE=C:\Users\s
V=0
WINDIR=C:\WINDOWS
***********************************************

real    0m0.306s
user    0m0.139s
sys     0m0.121s
Sage build/upgrade complete!
*** ALL ENVIRONMENT VARIABLES BEFORE BUILD: ***
!::=::\
_=/usr/bin/env
ALLUSERSPROFILE=C:\ProgramData
APPDATA=C:\Users\s\AppData\Roaming
CommonProgramFiles(x86)=C:\Program Files (x86)\Common Files
COMMONPROGRAMFILES=C:\Program Files\Common Files
CommonProgramW6432=C:\Program Files\Common Files
COMPUTERNAME=LAPTOP-Q6AFHV1S
COMSPEC=C:\WINDOWS\system32\cmd.exe
DriverData=C:\Windows\System32\Drivers\DriverData
EXECIGNORE=*.dll
FPS_BROWSER_APP_PROFILE_STRING=Internet Explorer
FPS_BROWSER_USER_PROFILE_STRING=Default
HOME=/home/s
HOMEDRIVE=C:
HOMEPATH=\Users\s
HOSTNAME=Uc
INFOPATH=/usr/local/info:/usr/share/info:/usr/info
LANG=en_US.utf8
LANGUAGE=en_US.utf8
LC_ALL=en_US.utf8
LC_CTYPE=en_US.utf8
LOCALAPPDATA=C:\Users\s\AppData\Local
LOGONSERVER=\\LAPTOP-Q6AFHV1S
MAKE_TERMERR=/dev/pty1
MAKE_TERMOUT=/dev/pty1
MAKE=make -j1
MAKEFLAGS=s -j1 -- V=0 V=1
MAKELEVEL=2
MAKEOVERRIDES=${-*-command-variables-*-}
MFLAGS=-s -j1
MINTTY_SHORTCUT=/cygdrive/c/Users/s/AppData/Roaming/Microsoft/Internet Explorer/Quick Launch/User Pinned/TaskBar/Cygwin64 Terminal.lnk
NUMBER_OF_PROCESSORS=8
OLDPWD=/home/s/sage-9-5-c1-from-tgz
OneDrive=C:\Users\s\OneDrive
ORIGINAL_PATH=/cygdrive/c/WINDOWS/system32:/cygdrive/c/WINDOWS:/cygdrive/c/WINDOWS/System32/Wbem:/cygdrive/c/WINDOWS/System32/WindowsPowerShell/v1.0:/cygdrive/c/WINDOWS/System32/OpenSSH:/cygdrive/c/Users/s/AppData/Local/Microsoft/WindowsApps
OS=Windows_NT
PATH=/home/s/sage-9-5-c1-from-tgz/build/bin:/home/s/sage-9-5-c1-from-tgz/src/bin:/home/s/sage-9-5-c1-from-tgz/local/bin:/usr/local/bin:/usr/bin:/cygdrive/c/WINDOWS/system32:/cygdrive/c/WINDOWS:/cygdrive/c/WINDOWS/System32/Wbem:/cygdrive/c/WINDOWS/System32/WindowsPowerShell/v1.0:/cygdrive/c/WINDOWS/System32/OpenSSH:/cygdrive/c/Users/s/AppData/Local/Microsoft/WindowsApps:/usr/lib/lapack
PATHEXT=.COM;.EXE;.BAT;.CMD;.VBS;.VBE;.JS;.JSE;.WSF;.WSH;.MSC
PRINTER=Microsoft Print to PDF
PROCESSOR_ARCHITECTURE=AMD64
PROCESSOR_IDENTIFIER=AMD64 Family 23 Model 24 Stepping 1, AuthenticAMD
PROCESSOR_LEVEL=23
PROCESSOR_REVISION=1801
PROFILEREAD=true
ProgramData=C:\ProgramData
ProgramFiles(x86)=C:\Program Files (x86)
PROGRAMFILES=C:\Program Files
ProgramW6432=C:\Program Files
PSModulePath=C:\Program Files\WindowsPowerShell\Modules;C:\WINDOWS\system32\WindowsPowerShell\v1.0\Modules
PUBLIC=C:\Users\Public
PWD=/home/s/sage-9-5-c1-from-tgz/build/make
PYTHONPATH=/home/s/sage-9-5-c1-from-tgz/local
SAGE_ENV_CONFIG_SOURCED=1
SAGE_LOCAL=/home/s/sage-9-5-c1-from-tgz/local
SAGE_LOGFILE=logs/install.log
SAGE_LOGS=/home/s/sage-9-5-c1-from-tgz/logs/pkgs
SAGE_NUM_THREADS_PARALLEL=1
SAGE_NUM_THREADS=1
SAGE_ORIG_PATH_SET=True
SAGE_ORIG_PATH=/usr/local/bin:/usr/bin:/cygdrive/c/WINDOWS/system32:/cygdrive/c/WINDOWS:/cygdrive/c/WINDOWS/System32/Wbem:/cygdrive/c/WINDOWS/System32/WindowsPowerShell/v1.0:/cygdrive/c/WINDOWS/System32/OpenSSH:/cygdrive/c/Users/s/AppData/Local/Microsoft/WindowsApps:/usr/lib/lapack
SAGE_PKGCONFIG=/home/s/sage-9-5-c1-from-tgz/local/lib/pkgconfig
SAGE_ROOT=/home/s/sage-9-5-c1-from-tgz
SAGE_SHARE=/home/s/sage-9-5-c1-from-tgz/local/share
SAGE_SILENT_BUILD=yes
SAGE_SRC=/home/s/sage-9-5-c1-from-tgz/src
SESSIONNAME=Console
SHELL=/bin/bash
SHLVL=4
SYSTEMDRIVE=C:
SYSTEMROOT=C:\WINDOWS
TEMP=/tmp
TERM_PROGRAM_VERSION=3.5.2
TERM_PROGRAM=mintty
TERM=xterm
TMP=/tmp
TZ=Europe/Paris
USER=s
USERDOMAIN_ROAMINGPROFILE=LAPTOP-Q6AFHV1S
USERDOMAIN=LAPTOP-Q6AFHV1S
USERNAME=s
USERPROFILE=C:\Users\s
V=0
WINDIR=C:\WINDOWS
***********************************************
make --no-print-directory /home/s/sage-9-5-c1-from-tgz/local/var/lib/sage/installed/.dummy
make --no-print-directory /home/s/sage-9-5-c1-from-tgz/local/var/lib/sage/installed/.dummy
make --no-print-directory /home/s/sage-9-5-c1-from-tgz/local/var/lib/sage/installed/.dummy
make --no-print-directory /home/s/sage-9-5-c1-from-tgz/local/var/lib/sage/installed/.dummy
[setuptools-59.2.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/setuptools-59.2.0.log
  [setuptools-59.2.0] successfully installed.
[wheel-0.37.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/wheel-0.37.0.log
  [wheel-0.37.0] successfully installed.
[pip-21.3.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/pip-21.3.1.log
  [pip-21.3.1] successfully installed.
[flit_core-3.4.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/flit_core-3.4.0.log
  [flit_core-3.4.0] successfully installed.
[tomli-1.2.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/tomli-1.2.1.log
  [tomli-1.2.1] successfully installed.
[pyparsing-3.0.6] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/pyparsing-3.0.6.log
  [pyparsing-3.0.6] successfully installed.
[setuptools_wheel-59.2.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/setuptools_wheel-59.2.0.log
  [setuptools_wheel-59.2.0] successfully installed.
[packaging-21.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/packaging-21.0.log
  [packaging-21.0] successfully installed.
[setuptools_scm-6.3.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/setuptools_scm-6.3.2.log
  [setuptools_scm-6.3.2] successfully installed.
[gmpy2-2.1.0rc1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/gmpy2-2.1.0rc1.log
  [gmpy2-2.1.0rc1] successfully installed.
[cython-0.29.24] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/cython-0.29.24.log
  [cython-0.29.24] successfully installed.
[pari_galdata-20080411.p0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/pari_galdata-20080411.p0.log
  [pari_galdata-20080411.p0] successfully installed.
[pari_seadata_small-20090618.p0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/pari_seadata_small-20090618.p0.log
  [pari_seadata_small-20090618.p0] successfully installed.
[pari-2.13.3] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/pari-2.13.3.log
  [pari-2.13.3] successfully installed.
[cysignals-1.11.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/cysignals-1.11.2.log
  [cysignals-1.11.2] successfully installed.
[ppl-1.2.p1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/ppl-1.2.p1.log
  [ppl-1.2.p1] successfully installed.
[pplpy-0.8.6] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/pplpy-0.8.6.log
  [pplpy-0.8.6] successfully installed.
[docutils-0.17.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/docutils-0.17.1.log
  [docutils-0.17.1] successfully installed.
[markupsafe-1.1.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/markupsafe-1.1.1.log
  [markupsafe-1.1.1] successfully installed.
[jinja2-2.11.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/jinja2-2.11.2.log
  [jinja2-2.11.2] successfully installed.
[pygments-2.10.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/pygments-2.10.0.log
  [pygments-2.10.0] successfully installed.
[six-1.16.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/six-1.16.0.log
  [six-1.16.0] successfully installed.
[snowballstemmer-2.1.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/snowballstemmer-2.1.0.log
  [snowballstemmer-2.1.0] successfully installed.
[imagesize-1.2.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/imagesize-1.2.0.log
  [imagesize-1.2.0] successfully installed.
[pytz-2021.3] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/pytz-2021.3.log
  [pytz-2021.3] successfully installed.
[babel-2.9.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/babel-2.9.1.log
  [babel-2.9.1] successfully installed.
[alabaster-0.7.12] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/alabaster-0.7.12.log
  [alabaster-0.7.12] successfully installed.
[idna-3.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/idna-3.2.log
  [idna-3.2] successfully installed.
[urllib3-1.26.6] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/urllib3-1.26.6.log
  [urllib3-1.26.6] successfully installed.
[certifi-2021.10.8] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/certifi-2021.10.8.log
  [certifi-2021.10.8] successfully installed.
[charset_normalizer-2.0.4] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/charset_normalizer-2.0.4.log
  [charset_normalizer-2.0.4] successfully installed.
[requests-2.26.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/requests-2.26.0.log
  [requests-2.26.0] successfully installed.
[sphinxcontrib_websupport-1.2.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/sphinxcontrib_websupport-1.2.1.log
  [sphinxcontrib_websupport-1.2.1] successfully installed.
[sphinxcontrib_applehelp-1.0.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/sphinxcontrib_applehelp-1.0.2.log
  [sphinxcontrib_applehelp-1.0.2] successfully installed.
[sphinxcontrib_devhelp-1.0.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/sphinxcontrib_devhelp-1.0.2.log
  [sphinxcontrib_devhelp-1.0.2] successfully installed.
[sphinxcontrib_htmlhelp-2.0.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/sphinxcontrib_htmlhelp-2.0.0.log
  [sphinxcontrib_htmlhelp-2.0.0] successfully installed.
[sphinxcontrib_jsmath-1.0.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/sphinxcontrib_jsmath-1.0.1.log
  [sphinxcontrib_jsmath-1.0.1] successfully installed.
[sphinxcontrib_qthelp-1.0.3] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/sphinxcontrib_qthelp-1.0.3.log
  [sphinxcontrib_qthelp-1.0.3] successfully installed.
[sphinxcontrib_serializinghtml-1.1.5] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/sphinxcontrib_serializinghtml-1.1.5.log
  [sphinxcontrib_serializinghtml-1.1.5] successfully installed.
[sphinx-4.2.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/sphinx-4.2.0.log
  [sphinx-4.2.0] successfully installed.
[pplpy_doc-0.8.6] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/pplpy_doc-0.8.6.log
  [pplpy_doc-0.8.6] successfully installed.
[arb-2.19.0.p0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/arb-2.19.0.p0.log
  [arb-2.19.0.p0] successfully installed.
[openblas-0.3.18] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/openblas-0.3.18.log
  [openblas-0.3.18] successfully installed.
[m4ri-20200115] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/m4ri-20200115.log
  [m4ri-20200115] successfully installed.
[brial-1.2.8] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/brial-1.2.8.log
   [brial-1.2.8] successfully installed.
[cliquer-1.22] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/cliquer-1.22.log
  [cliquer-1.22] successfully installed.
[cypari-2.1.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/cypari-2.1.2.log
  [cypari-2.1.2] successfully installed.
[ecl-21.2.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/ecl-21.2.1.log
  [ecl-21.2.1] successfully installed.
[eclib-20210625] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/eclib-20210625.log
  [eclib-20210625] successfully installed.
[ecm-7.0.4.p2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/ecm-7.0.4.p2.log
  [ecm-7.0.4.p2] successfully installed.
[gap-4.11.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/gap-4.11.1.log
  [gap-4.11.1] successfully installed.
[mpfi-1.5.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/mpfi-1.5.2.log
  [mpfi-1.5.2] successfully installed.
[gsl-2.7] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/gsl-2.7.log
  [gsl-2.7] successfully installed.
[giac-1.6.0.47p3] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/giac-1.6.0.47p3.log
  [giac-1.6.0.47p3] successfully installed.
[givaro-4.1.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/givaro-4.1.1.log
  [givaro-4.1.1] successfully installed.
[iml-1.0.4p1.p2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/iml-1.0.4p1.p2.log
  [iml-1.0.4p1.p2] successfully installed.
[ipython_genutils-0.2.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/ipython_genutils-0.2.0.log
  [ipython_genutils-0.2.0] successfully installed.
[decorator-4.4.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/decorator-4.4.2.log
  [decorator-4.4.2] successfully installed.
[traitlets-5.1.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/traitlets-5.1.1.log
  [traitlets-5.1.1] successfully installed.
[jupyter_core-4.9.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/jupyter_core-4.9.1.log
  [jupyter_core-4.9.1] successfully installed.
[lcalc-2.0.5] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/lcalc-2.0.5.log
  [lcalc-2.0.5] successfully installed.
[lrcalc-1.2.p1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/lrcalc-1.2.p1.log
  [lrcalc-1.2.p1] successfully installed.
[libbraiding-1.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/libbraiding-1.1.log
  [libbraiding-1.1] successfully installed.
[libhomfly-1.02r6] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/libhomfly-1.02r6.log
  [libhomfly-1.02r6] successfully installed.
[fplll-5.4.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/fplll-5.4.1.log
  [fplll-5.4.1] successfully installed.
[fflas_ffpack-2.4.3.p0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/fflas_ffpack-2.4.3.p0.log
  [fflas_ffpack-2.4.3.p0] successfully installed.
[linbox-1.6.3.p1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/linbox-1.6.3.p1.log
  [linbox-1.6.3.p1] successfully installed.
[m4rie-20200115] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/m4rie-20200115.log
  [m4rie-20200115] successfully installed.
[memory_allocator-0.1.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/memory_allocator-0.1.1.log
  [memory_allocator-0.1.1] successfully installed.
[pkgconfig-1.5.5] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/pkgconfig-1.5.5.log
  [pkgconfig-1.5.5] successfully installed.
[numpy-1.21.4] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/numpy-1.21.4.log
  [numpy-1.21.4] successfully installed.
[planarity-3.0.1.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/planarity-3.0.1.0.log
  [planarity-3.0.1.0] successfully installed.
[primesieve-7.6] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/primesieve-7.6.log
  [primesieve-7.6] successfully installed.
[primecount-7.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/primecount-7.1.log
  [primecount-7.1] successfully installed.
[primecountpy-0.1.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/primecountpy-0.1.0.log
  [primecountpy-0.1.0] successfully installed.
[pycygwin-0.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/pycygwin-0.1.log
  [pycygwin-0.1] successfully installed.
[ratpoints-2.1.3.p5] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/ratpoints-2.1.3.p5.log
  [ratpoints-2.1.3.p5] successfully installed.
[rw-0.9] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/rw-0.9.log
  [rw-0.9] successfully installed.
[sage_conf-9.5.rc1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/sage_conf-9.5.rc1.log
  [sage_conf-9.5.rc1] successfully installed.
[singular-4.2.1p3] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/singular-4.2.1p3.log
  [singular-4.2.1p3] successfully installed.
[symmetrica-3.0.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/symmetrica-3.0.1.log
  [symmetrica-3.0.1] successfully installed.
[zn_poly-0.9.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/zn_poly-0.9.2.log
  [zn_poly-0.9.2] successfully installed.
[sage_setup-9.5.rc1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/sage_setup-9.5.rc1.log
  [sage_setup-9.5.rc1] successfully installed.
[sagelib-9.5.rc1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/sagelib-9.5.rc1.log
  [sagelib-9.5.rc1] successfully installed.
[tornado-6.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/tornado-6.1.log
  [tornado-6.1] successfully installed.
[zeromq-4.3.4] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/zeromq-4.3.4.log
  [zeromq-4.3.4] successfully installed.
[pyzmq-22.3.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/pyzmq-22.3.0.log
  [pyzmq-22.3.0] successfully installed.
[pickleshare-0.7.5] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/pickleshare-0.7.5.log
  [pickleshare-0.7.5] successfully installed.
[simplegeneric-0.8.1.p0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/simplegeneric-0.8.1.p0.log
  [simplegeneric-0.8.1.p0] successfully installed.
[wcwidth-0.2.5] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/wcwidth-0.2.5.log
  [wcwidth-0.2.5] successfully installed.
[prompt_toolkit-3.0.22] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/prompt_toolkit-3.0.22.log
  [prompt_toolkit-3.0.22] successfully installed.
[ptyprocess-0.5.1.p0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/ptyprocess-0.5.1.p0.log
  [ptyprocess-0.5.1.p0] successfully installed.
[pexpect-4.8.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/pexpect-4.8.0.log
  [pexpect-4.8.0] successfully installed.
[appnope-0.1.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/appnope-0.1.2.log
  [appnope-0.1.2] successfully installed.
[backcall-0.2.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/backcall-0.2.0.log
  [backcall-0.2.0] successfully installed.
[parso-0.8.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/parso-0.8.2.log
  [parso-0.8.2] successfully installed.
[jedi-0.18.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/jedi-0.18.1.log
  [jedi-0.18.1] successfully installed.
[ipython-7.29.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/ipython-7.29.0.log
  [ipython-7.29.0] successfully installed.
[maxima-5.45.0.p0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/maxima-5.45.0.p0.log
  [maxima-5.45.0.p0] successfully installed.
[pybind11-2.8.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/pybind11-2.8.1.log
  [pybind11-2.8.1] successfully installed.
[gast-0.5.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/gast-0.5.2.log
  [gast-0.5.2] successfully installed.
[beniget-0.4.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/beniget-0.4.1.log
  [beniget-0.4.1] successfully installed.
[ply-3.11] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/ply-3.11.log
  [ply-3.11] successfully installed.
[pythran-0.10.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/pythran-0.10.0.log
  [pythran-0.10.0] successfully installed.
[scipy-1.7.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/scipy-1.7.2.log
  [scipy-1.7.2] successfully installed.
[networkx-2.6.3] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/networkx-2.6.3.log
  [networkx-2.6.3] successfully installed.
[mpmath-1.2.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/mpmath-1.2.1.log
  [mpmath-1.2.1] successfully installed.
[sympy-1.9] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/sympy-1.9.log
  [sympy-1.9] successfully installed.
[pillow-8.4.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/pillow-8.4.0.log
  [pillow-8.4.0] successfully installed.
[dateutil-2.8.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/dateutil-2.8.2.log
  [dateutil-2.8.2] successfully installed.
[cycler-0.11.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/cycler-0.11.0.log
  [cycler-0.11.0] successfully installed.
[fonttools-4.28.4] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/fonttools-4.28.4.log
  [fonttools-4.28.4] successfully installed.
[cppy-1.1.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/cppy-1.1.0.log
  [cppy-1.1.0] successfully installed.
[kiwisolver-1.3.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/kiwisolver-1.3.2.log
  [kiwisolver-1.3.2] successfully installed.
[setuptools_scm_git_archive-1.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/setuptools_scm_git_archive-1.1.log
  [setuptools_scm_git_archive-1.1] successfully installed.
[matplotlib-3.5.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/matplotlib-3.5.1.log
  [matplotlib-3.5.1] successfully installed.
[mathjax-2.7.4.p0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/mathjax-2.7.4.p0.log
  [mathjax-2.7.4.p0] successfully installed.
[vcversioner-2.16.0.0.p0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/vcversioner-2.16.0.0.p0.log
  [vcversioner-2.16.0.0.p0] successfully installed.
[zipp-3.5.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/zipp-3.5.0.log
  [zipp-3.5.0] successfully installed.
[typing_extensions-3.10.0.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/typing_extensions-3.10.0.0.log
  [typing_extensions-3.10.0.0] successfully installed.
[importlib_metadata-4.8.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/importlib_metadata-4.8.2.log
  [importlib_metadata-4.8.2] successfully installed.
[argcomplete-1.12.3] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/argcomplete-1.12.3.log
  [argcomplete-1.12.3] successfully installed.
[matplotlib_inline-0.1.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/matplotlib_inline-0.1.2.log
  [matplotlib_inline-0.1.2] successfully installed.
[nest_asyncio-1.5.1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/nest_asyncio-1.5.1.log
  [nest_asyncio-1.5.1] successfully installed.
[entrypoints-0.3] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/entrypoints-0.3.log
  [entrypoints-0.3] successfully installed.
[jupyter_client-7.1.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/jupyter_client-7.1.0.log
  [jupyter_client-7.1.0] successfully installed.
[ipykernel-6.6.0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/ipykernel-6.6.0.log
  [ipykernel-6.6.0] successfully installed.
[conway_polynomials-0.5] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/conway_polynomials-0.5.log
  [conway_polynomials-0.5] successfully installed.
[tachyon-0.98.9.p7] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/tachyon-0.98.9.p7.log
  [tachyon-0.98.9.p7] successfully installed.
[jmol-14.29.52] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/jmol-14.29.52.log
  [jmol-14.29.52] successfully installed.
[thebe-9624e0a0.p0] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/thebe-9624e0a0.p0.log
  [thebe-9624e0a0.p0] successfully installed.
[widgetsnbextension-3.5.2] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/widgetsnbextension-3.5.2.log
  [widgetsnbextension-3.5.2] successfully installed.
[ipywidgets-7.6.5] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/ipywidgets-7.6.5.log
  [ipywidgets-7.6.5] successfully installed.
[sage_docbuild-9.5.rc1] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/sage_docbuild-9.5.rc1.log
  [sage_docbuild-9.5.rc1] successfully installed.
[sagemath_doc_html-none] installing. Log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/sagemath_doc_html-none.log
  [sagemath_doc_html-none] error installing, exit status 2. End of log file:
  [sagemath_doc_html-none]   [reference] WARNING: Unable to fetch /home/s/sage-9-5-c1-from-tgz/local/share/doc/sage/doctrees/en/reference/categories/environment.pickle
  [sagemath_doc_html-none]   [reference] WARNING: Unable to fetch /home/s/sage-9-5-c1-from-tgz/local/share/doc/sage/doctrees/en/reference/coding/environment.pickle
  [sagemath_doc_html-none]   [reference] WARNING: Unable to fetch /home/s/sage-9-5-c1-from-tgz/local/share/doc/sage/doctrees/en/reference/combinat/environment.pickle
  [sagemath_doc_html-none]   [reference] WARNING: Unable to fetch /home/s/sage-9-5-c1-from-tgz/local/share/doc/sage/doctrees/en/reference/graphs/environment.pickle
  [sagemath_doc_html-none]   [reference] WARNING: Unable to fetch /home/s/sage-9-5-c1-from-tgz/local/share/doc/sage/doctrees/en/reference/groups/environment.pickle
  [sagemath_doc_html-none]   [reference] WARNING: Unable to fetch /home/s/sage-9-5-c1-from-tgz/local/share/doc/sage/doctrees/en/reference/knots/environment.pickle
  [sagemath_doc_html-none]   [reference] WARNING: Unable to fetch /home/s/sage-9-5-c1-from-tgz/local/share/doc/sage/doctrees/en/reference/libs/environment.pickle
  [sagemath_doc_html-none]   [reference] preparing documents... skipping loading of indexes... done
  [sagemath_doc_html-none]   [reference] /home/s/sage-9-5-c1-from-tgz/src/doc/en/reference/index.rst:35: WARNING: unknown document: categories/index
  [sagemath_doc_html-none]   [reference] /home/s/sage-9-5-c1-from-tgz/src/doc/en/reference/index.rst:77: WARNING: unknown document: groups/index
  [sagemath_doc_html-none]   [reference] /home/s/sage-9-5-c1-from-tgz/src/doc/en/reference/index.rst:80: WARNING: unknown document: algebras/index
  [sagemath_doc_html-none]   [reference] /home/s/sage-9-5-c1-from-tgz/src/doc/en/reference/index.rst:85: WARNING: unknown document: combinat/index
  [sagemath_doc_html-none]   [reference] /home/s/sage-9-5-c1-from-tgz/src/doc/en/reference/index.rst:86: WARNING: unknown document: graphs/index
  [sagemath_doc_html-none]   [reference] /home/s/sage-9-5-c1-from-tgz/src/doc/en/reference/index.rst:90: WARNING: unknown document: coding/index
  [sagemath_doc_html-none]   [reference] /home/s/sage-9-5-c1-from-tgz/src/doc/en/reference/index.rst:105: WARNING: unknown document: knots/index
  [sagemath_doc_html-none]   [reference] /home/s/sage-9-5-c1-from-tgz/src/doc/en/reference/index.rst:156: WARNING: unknown document: libs/index
  [sagemath_doc_html-none]   [reference] The inventory files are in local/share/doc/sage/inventory/en/reference.
  [sagemath_doc_html-none]   Error building the documentation.
  [sagemath_doc_html-none]   Traceback (most recent call last):
  [sagemath_doc_html-none]     File "/usr/lib/python3.9/runpy.py", line 197, in _run_module_as_main
  [sagemath_doc_html-none]       return _run_code(code, main_globals, None,
  [sagemath_doc_html-none]     File "/usr/lib/python3.9/runpy.py", line 87, in _run_code
  [sagemath_doc_html-none]       exec(code, run_globals)
  [sagemath_doc_html-none]     File "/home/s/sage-9-5-c1-from-tgz/local/var/lib/sage/venv-python3.9/lib/python3.9/site-packages/sage_docbuild/__main__.py", line 2, in <module>
  [sagemath_doc_html-none]       main()
  [sagemath_doc_html-none]     File "/home/s/sage-9-5-c1-from-tgz/local/var/lib/sage/venv-python3.9/lib/python3.9/site-packages/sage_docbuild/__init__.py", line 1775, in main
  [sagemath_doc_html-none]       builder()
  [sagemath_doc_html-none]     File "/home/s/sage-9-5-c1-from-tgz/local/var/lib/sage/venv-python3.9/lib/python3.9/site-packages/sage_docbuild/__init__.py", line 137, in f
  [sagemath_doc_html-none]       runsphinx()
  [sagemath_doc_html-none]     File "/home/s/sage-9-5-c1-from-tgz/local/var/lib/sage/venv-python3.9/lib/python3.9/site-packages/sage_docbuild/sphinxbuild.py", line 323, in runsphinx
  [sagemath_doc_html-none]       sys.stderr.raise_errors()
  [sagemath_doc_html-none]     File "/home/s/sage-9-5-c1-from-tgz/local/var/lib/sage/venv-python3.9/lib/python3.9/site-packages/sage_docbuild/sphinxbuild.py", line 258, in raise_errors
  [sagemath_doc_html-none]       raise OSError(self._error)
  [sagemath_doc_html-none]   OSError: WARNING: Unable to fetch /home/s/sage-9-5-c1-from-tgz/local/share/doc/sage/doctrees/en/reference/algebras/environment.pickle
  [sagemath_doc_html-none]
  [sagemath_doc_html-none]       Note: incremental documentation builds sometimes cause spurious
  [sagemath_doc_html-none]       error messages. To be certain that these are real errors, run
  [sagemath_doc_html-none]       "make doc-clean doc-uninstall" first and try again.
  [sagemath_doc_html-none]   make[6]: *** [Makefile:20: doc-inventory--reference_top] Error 1
  [sagemath_doc_html-none]   make[5]: *** [Makefile:38: doc-inventory-reference] Error 2
  [sagemath_doc_html-none] Full log file: /home/s/sage-9-5-c1-from-tgz/logs/pkgs/sagemath_doc_html-none.log
make[4]: *** [Makefile:2866: sagemath_doc_html-SAGE_DOCS-no-deps] Error 2
make[3]: *** [Makefile:2866: /home/s/sage-9-5-c1-from-tgz/local/var/lib/sage/installed/sagemath_doc_html-none] Error 2
make[2]: *** [Makefile:2427: all-start] Error 2

real    928m7.762s
user    812m41.784s
sys     213m1.478s
***************************************************************
Error building Sage.

The following package(s) may have failed to build (not necessarily
during this run of 'make all-start'):

It is safe to delete any log files and build directories, but they
contain information that is helpful for debugging build problems.
WARNING: If you now run 'make' again, the build directory of the
same version of the package will, by default, be deleted. Set the
environment variable SAGE_KEEP_BUILT_SPKGS=yes to prevent this.

make[1]: *** [Makefile:39: all-start] Error 1
make: *** [Makefile:13: all] Error 2
```
